@@ -1,9 +1,11 @@
 from __future__ import annotations
 
+from ctypes import pointer
 from types import MappingProxyType
 from typing import TypeVar
 
 from einspect.compat import abc
+from einspect.structs import PyDictObject
 from einspect.structs.mapping_proxy import MappingProxyObject
 from einspect.views.unsafe import unsafe
 from einspect.views.view_base import View, REF_DEFAULT
@@ -45,4 +47,4 @@ class MappingProxyView(View[MappingProxyType, _KT, _VT], abc.MutableMapping[_KT,
     @mapping.setter
     @unsafe
     def mapping(self, value: dict[_KT, _VT]) -> None:
-        self._pyobject.mapping = value
+        self._pyobject.mapping = pointer(PyDictObject.from_object(value))
